@@ -210,4 +210,19 @@ class Email:
         Delete an email message.
         :param msg: The email message to delete.
         """
-        msg.delete()
\ No newline at end of file
+        msg.delete()
+
+    def save_attachments(self, msg, folderpath):
+        """
+        Save all attachments of the email message to the specified folder
+        :param msg: The email message object.
+        :param folderpath: The path to the folder where the attachments will be saved.
+        :return: A list with the attachment filenames
+        """
+        retn = []
+        for attachment in msg.attachments:
+            retn.append(attachment.name)
+            fpath = os.path.join(folderpath, attachment.name)
+            with open(fpath, 'wb') as f:
+                f.write(attachment.content)
+        return retn
